:notoc:

.. abil documentation master file

*******
Abil.py
*******

*Aquatic Biogeochemical Interpolation Library in Python*

Abil.py is a `Python <https://www.python.org/>`__ library to interpolate distributions of biogeochemical observations using Machine Learning algorithms in Python. 
The library is optimized to interpolate many predictions in parallel and is thus particularly suited for distribution models of species, 
genes and transcripts. The library relies on `scikit-learn <https://scikit-learn.org/stable/>`_, `numpy <https://numpy.org/>`_, `pandas <https://pandas.pydata.org/>`_, 
`scikit-bio <https://scikit.bio/>`_.

.. toctree::
   :maxdepth: 3
   :hidden:
   :titlesonly:

   source/getting-started/index
   source/user-guide/index
   source/reference/index
   source/development/index
